Switch from unmaintained gothub uploader to github-release

Change-Id: I76c7590948daf7ff30de99268b2011fb1089252b
diff --git a/jjb/shell/github-release.sh b/jjb/shell/github-release.sh
index 40705c6..80b346f 100644
--- a/jjb/shell/github-release.sh
+++ b/jjb/shell/github-release.sh
@@ -95,7 +95,7 @@
 
   # create release
   echo "Creating Release: $GERRIT_PROJECT - $GIT_VERSION"
-  gothub release \
+  github-release release \
     --user "$GITHUB_ORGANIZATION" \
     --repo "$GERRIT_PROJECT" \
     --tag  "$GIT_VERSION" \
@@ -116,7 +116,7 @@
     for rel_file in *
     do
       echo "Uploading file: $rel_file"
-      gothub upload \
+      github-release upload \
         --user "$GITHUB_ORGANIZATION" \
         --repo "$GERRIT_PROJECT" \
         --tag  "$GIT_VERSION" \
diff --git a/packer/provision/basebuild.sh b/packer/provision/basebuild.sh
index 95d0307..18f2d89 100644
--- a/packer/provision/basebuild.sh
+++ b/packer/provision/basebuild.sh
@@ -193,8 +193,8 @@
     go get -v github.com/t-yuki/gocover-cobertura
     go get -v github.com/jstemmer/go-junit-report
 
-    # gothub - uploader for github artifacts
-    go get -v github.com/itchio/gothub
+    # github-release - uploader for github artifacts
+    go get -v github.com/github-release/github-release
 
     # dep for go package dependencies w/versioning, version 0.5.2, adapted from:
     #  https://golang.github.io/dep/docs/installation.html#install-from-source